@@ -16,7 +16,7 @@ sub new {
 
     # Check attributes
     my $attrs;
-    if (exists $_[1]) {
+    if ($_[1]) {
         my %attrs = (@_);
         $attrs = \%attrs;
     }
@@ -25,13 +25,22 @@ sub new {
 
     # Create instance
     my $class = ref $proto || $proto;
-    my $self = bless $attrs, $class;
+    my $self = bless {}, $class;
+
+    # Attributes
+    for my $attr (keys %$attrs) {
+
+        # Attribute
+        if ($self->can($attr)) { $self->$attr($attrs->{$attr}) }
+
+        # No attribute, pass through to instance hash
+        else { $self->{$attr} = $attrs->{$attr} }
+    }
 
     return $self;
 }
 
-# Performance is very important for something as often used as accessors,
-# so we optimize them by compiling our own code
+# Here's to alcohol, the cause of—and solution to—all life's problems.
 sub attr {
     my $class = shift;
     my $attrs = shift;
@@ -41,15 +50,19 @@ sub attr {
 
     # Check options
     my $options;
-    if (exists $_[1]) {
+    if ($_[1]) {
         my %options = (@_);
         $options = \%options;
     }
     else { $options = $_[0] }
     $options ||= {};
 
+    Carp::croak('Option "filter" has to be a coderef')
+      if ($options->{filter} && !ref $options->{filter} eq 'CODE');
+
     my $chained = delete $options->{chained};
     my $default = delete $options->{default};
+    my $filter  = delete $options->{filter};
     my $weak    = delete $options->{weak};
 
     undef $options;
@@ -62,63 +75,72 @@ sub attr {
     my $ws = '    ';
     for my $attr (@$attrs) {
 
-        Carp::croak("Attribute '$attr' invalid")
-          unless $attr =~ /^[a-zA-Z_]\w*$/;
-
         # Header
         my $code = "sub {\n";
+        $code .= "${ws}my \$self = shift;\n";
+        $code .= "${ws}Carp::croak(\'";
+        $code .= 'Attribute has to be called with an object not a class';
+        $code .= "')\n  ${ws}unless ref \$self;\n";
 
-        # Warning gets optimized away
-        unless ($ENV{MOJO_BASE_OPTIMIZE}) {
-
-            # Check invocant
-            $code .= "${ws}Carp::croak(\'";
-            $code .= 'Attribute has to be called with an object not a class';
-            $code .= "')\n  ${ws}unless ref \$_[0];\n";
-        }
-
-        # No value
-        $code .= "${ws}if (\@_ == 1) {\n";
-        unless (defined $default) {
+        # No arguments
+        $code .= "${ws}if (\@_ == 0) {\n";
+        unless ($default) {
 
             # Return value
-            $code .= "$ws${ws}return \$_[0]->{'$attr'};\n";
+            $code .= "$ws${ws}return \$self->{\$attr};\n";
         }
         else {
 
             # Return value
-            $code .= "$ws${ws}return \$_[0]->{'$attr'} ";
-            $code .= "if exists \$_[0]->{'$attr'};\n";
+            $code .= "$ws${ws}return \$self->{\$attr} ";
+            $code .= "if defined \$self->{\$attr};\n";
 
             # Return default value
-            $code .= "$ws${ws}return \$_[0]->{'$attr'} = ";
+            $code .= "$ws${ws}return \$self->{\$attr} = ";
             $code .= ref $default eq 'CODE'
-              ? '$default->($_[0])'
+              ? '$default->($self)'
               : '$default';
             $code .= ";\n";
         }
         $code .= "$ws}\n";
 
+        # Single argument
+        $code .= "${ws}elsif (\@_ == 1) { \n";
+        if ($filter) {
 
-        # Store argument optimized
-        if (!$weak && !$chained) {
-            $code .= "${ws}return \$_[0]->{'$attr'} = \$_[1];\n";
+            # Filter and store argument
+            $code .= "$ws${ws}local \$_ = \$_[0];\n";
+            $code .= "$ws$ws\$self->{\$attr} = \$filter->(\$self, \$_);\n";
         }
-
-        # Store argument the old way
         else {
-            $code .= "$ws\$_[0]->{'$attr'} = \$_[1];\n";
+
+            # Store argument
+            $code .= "$ws$ws\$self->{\$attr} = \$_[0];\n";
         }
+        $code .= "$ws}\n";
+
+        # Multiple arguments
+        $code .= "${ws}else {\n";
+        if ($filter) {
+
+            # Filter and store arguments
+            $code .= "$ws${ws}local \$_ = \\\@_;\n";
+            $code .= "$ws$ws\$self->{\$attr} = \$filter->(\$self, \$_);\n";
+        }
+        else {
+
+            # Store arguments
+            $code .= "$ws$ws\$self->{\$attr} = \\\@_;\n";
+        }
+        $code .= "$ws}\n";
 
         # Weaken
-        $code .= "${ws}Scalar::Util::weaken(\$_[0]->{'$attr'});\n" if $weak;
+        $code .= "${ws}Scalar::Util::weaken(\$self->{\$attr});\n" if $weak;
 
-        # Return value or instance for chained/weak
-        if ($chained || $weak) {
-            $code .= "${ws}return ";
-            $code .= $chained ? '$_[0]' : "\$_[0]->{'$attr'}";
-            $code .= ";\n";
-        }
+        # Return value or instance for chained
+        $code .= "${ws}return ";
+        $code .= $chained ? '$self' : '$self->{$attr}';
+        $code .= ";\n";
 
         # Footer
         $code .= '};';
@@ -142,7 +164,7 @@ __END__
 
 =head1 NAME
 
-Mojo::Base - Once Upon A Midnight Dreary!
+Mojo::Base - Once Upon A Midnight Dreary
 
 =head1 SYNOPSIS
 
@@ -150,7 +172,10 @@ Mojo::Base - Once Upon A Midnight Dreary!
     use base 'Mojo::Base';
 
     __PACKAGE__->attr('driver');
-    __PACKAGE__->attr('doors', default => 2);
+    __PACKAGE__->attr('doors',
+        default => 2,
+        filter  => sub { s/\D//g; $_ }
+    );
     __PACKAGE__->attr([qw/passengers seats/],
         chained => 1,
         default => sub { 2 }
@@ -171,16 +196,15 @@ Mojo::Base - Once Upon A Midnight Dreary!
 
 =head1 DESCRIPTION
 
-L<Mojo::Base> is a base class containing simple and fast helpers for object
-oriented Perl programming.
+L<Mojo::Base> is a universal base class containing simple and fast helpers
+for object oriented Perl programming.
 
 Main design goals are minimalism and staying out of your way.
 
-The syntax is a bit like Ruby and the performance better than
+The syntax is a bit like L<Moose> or Ruby and the performance close to
 L<Class::Accessor::Fast>.
-
-Note that this is just an accessor generator, take L<Moose> if you are
-looking for an object system that.
+(Note that L<Mojo::Base> was never meant as a replacement for L<Moose>, both
+are solutions to completely different problems.)
 
 For debugging you can set the C<MOJO_BASE_DEBUG> environment variable.
 
@@ -212,6 +236,8 @@ Currently there are four options supported.
              Note that the default value is "lazy", which means it only
              gets assigned to the instance after the attribute has been
              called.
+    filter:  Filters the value before assigning it to the instance,
+             must be a coderef.
     weak:    Weakens the attribute value.
 
 =cut
\ No newline at end of file
