@@ -8,6 +8,7 @@ use warnings;
 use base 'Mojo::Server';
 
 use Carp 'croak';
+use Mojo::Transaction;
 use IO::Select;
 use IO::Socket;
 
@@ -36,14 +37,11 @@ sub listen {
     # Create socket
     my $port = $self->port;
     $self->{listen} ||= IO::Socket::INET->new(
+        Blocking  => 0,
         Listen    => $self->listen_queue_size,
         LocalPort => $port,
-        Proto     => 'tcp',
-        ReuseAddr => 1,
-        Type      => SOCK_STREAM
+        Reuse     => 1
     ) or croak "Can't create listen socket: $!";
-
-    # Non blocking
     $self->{listen}->blocking(0);
 
     # Friendly message
@@ -125,8 +123,9 @@ sub _prepare_select {
     for my $name (keys %{$self->{_connections}}) {
         my $connection = $self->{_connections}->{$name};
 
-        # Transaction
-        my $tx = $connection->{tx};
+        # Normal transaction or 100 Continue
+        my $tx = $connection->{continue};
+        $tx    = $connection->{tx} unless $tx;
 
         # Keep alive timeout
         my $timeout = time - $connection->{time};
@@ -177,8 +176,9 @@ sub _prepare_transactions {
             next;
         }
 
-        # Transaction
-        my $tx = $connection->{tx};
+        # Normal transaction or 100 Continue
+        my $tx = $connection->{continue};
+        $tx    = $connection->{tx} unless $tx;
 
         # Just a keep alive, no transaction
         next unless $tx;
@@ -186,16 +186,6 @@ sub _prepare_transactions {
         # Writing
         if ($tx->is_state('write')) {
 
-            # Connection header
-            unless ($tx->res->headers->connection) {
-                if ($tx->keep_alive) {
-                    $tx->res->headers->connection('Keep-Alive');
-                }
-                else {
-                    $tx->res->headers->connection('Close');
-                }
-            }
-
             # Ready for next state
             $tx->state('write_start_line');
             $tx->{_to_write} = $tx->res->start_line_length;
@@ -219,11 +209,9 @@ sub _prepare_transactions {
         if ($tx->is_state('write_body') && $tx->{_to_write} <= 0) {
 
             # Continue done
-            if (defined $tx->continued && $tx->continued == 0) {
-                $tx->continued(1);
-                $tx->state('read');
-                $tx->done unless $tx->res->code == 100;
-                $tx->res->code(0);
+            if ($connection->{continue}) {
+                delete $connection->{continue};
+                $connection->{continued} = 1;
                 next;
             }
 
@@ -256,15 +244,11 @@ sub _read {
 
     my $connection = $self->{_connections}->{$name};
     unless ($connection->{tx}) {
-        my $tx = $connection->{tx} ||= $self->build_tx_cb->($self);
-        $tx->connection($socket);
-        $tx->state('read');
+        $connection->{tx} = Mojo::Transaction->new({
+            connection => $socket,
+            state      => 'read'
+        });
         $connection->{requests}++;
-        $tx->kept_alive(1) if $connection->{requests} > 1;
-
-        # Last keep alive request?
-        $tx->res->headers->connection('Close')
-          if $connection->{requests} >= $self->max_keep_alive_requests;
     }
 
     my $tx  = $connection->{tx};
@@ -283,11 +267,11 @@ sub _read {
     $req->parse($buffer);
 
     # Expect 100 Continue?
-    if ($req->content->is_state('body') && !defined $tx->continued) {
+    if ($req->is_state('body') && !$connection->{continued}) {
         if (($req->headers->expect || '') =~ /100-continue/i) {
-            $tx->state('write');
-            $tx->continued(0);
-            $self->continue_handler_cb->($self, $tx);
+            $connection->{continue}
+              = Mojo::Transaction->new({state => 'write'});
+            $connection->{continue}->res->code(100);
         }
     }
 
@@ -296,24 +280,16 @@ sub _read {
         $tx->state('write');
 
         # Handle
-        $self->handler_cb->($self, $tx);
+        $self->handler->($self, $tx);
     }
 
     $connection->{time} = time;
 }
 
 sub _socket_name {
-    my ($self, $s) = @_;
-
-    # Connected?
-    return undef unless $s->connected;
-
-    my $n = join ':', $s->sockaddr, $s->sockport, $s->peeraddr, $s->peerport;
-
-    # Temporary workaround for win32 weirdness
-    $n =~ s/[^\w]/x/gi;
-
-    return $n;
+    my ($self, $socket) = @_;
+    return undef unless $socket->connected;
+    return $socket->peeraddr . ':' . $socket->peerport;
 }
 
 sub _write {
@@ -325,26 +301,29 @@ sub _write {
     for my $socket (@$sockets) {
         next unless $name = $self->_socket_name($socket);
         my $connection = $self->{_connections}->{$name};
-        $tx  = $connection->{tx};
+        $tx  = $connection->{continue};
+        $tx  = $connection->{tx} unless $tx;
         $res = $tx->res;
 
+        # Wrong state
+        last unless $tx->is_state('write_body');
+
         # Body
-        $chunk = $res->get_body_chunk($tx->{_offset} || 0)
-          if $tx->is_state('write_body');
-
-        # Headers
-        $chunk = $res->get_header_chunk($tx->{_offset} || 0)
-          if $tx->is_state('write_headers');
-
-        # Start line
-        $chunk = $res->get_start_line_chunk($tx->{_offset} || 0)
-          if $tx->is_state('write_start_line');
+        $chunk = $res->get_body_chunk($tx->{_offset} || 0);
 
         # Content generator ready?
         last if defined $chunk;
     }
     return 0 unless $name;
 
+    # Headers
+    $chunk = $res->get_header_chunk($tx->{_offset} || 0)
+      if $tx->is_state('write_headers');
+
+    # Start line
+    $chunk = $res->get_start_line_chunk($tx->{_offset} || 0)
+      if $tx->is_state('write_start_line');
+
     # Write chunk
     return 0 unless $tx->connection->connected;
     my $written = $tx->connection->syswrite($chunk, length $chunk);
@@ -362,13 +341,13 @@ __END__
 
 =head1 NAME
 
-Mojo::Server::Daemon - HTTP Server
+Mojo::Server::Daemon - Simple HTTP Server
 
 =head1 SYNOPSIS
 
-    use Mojo::Server::Daemon;
+    use Mojo::Daemon;
 
-    my $daemon = Mojo::Server::Daemon->new;
+    my $daemon = Mojo::Daemon->new;
     $daemon->port(8080);
     $daemon->run;
 
@@ -432,4 +411,4 @@ implements the following new ones.
 
     $daemon->spin;
 
-=cut
+=cut
\ No newline at end of file
